confirm_auth_rpc_disclosure

Function confirm_auth_rpc_disclosure 

pub(super) fn confirm_auth_rpc_disclosure<N: Network, P, S>(
    builder: &CastTxBuilder<N, P, S>,
    sender: &SenderKind<'_>,
    force: bool,
) -> Result<bool>
Validates the authorization sender and confirms that the user intends to disclose an EIP-7702 authorization to an RPC endpoint.

Returns false when the user declines and the command should exit without sending the authorization.